Metadata bundle
---------------
The metadata bundle contains all modules related to records and metadata
management including e.g. records storage, persistent identifier management,
search engine indexing, an OAI-PMH server and REST APIs for records.

Included modules:

- `invenio-indexer <https://invenio-indexer.readthedocs.io>`_
    - Highly scalable record bulk indexing.
- `invenio-jsonschemas <https://invenio-jsonschemas.readthedocs.io>`_
    - JSONSchema registry for Invenio.
- `invenio-oaiserver <https://invenio-oaiserver.readthedocs.io>`_
    - OAI-PMH server implementation for Invenio.
- `invenio-pidstore <https://invenio-pidstore.readthedocs.io>`_
    - Management, registration and resolution of persistent identifiers
      including e.g DOIs.
- `invenio-records <https://invenio-records.readthedocs.io>`_
    - JSON document storage with revision history and JSONSchema validation.
- `invenio-records-rest <https://invenio-records-rest.readthedocs.io>`_
    - REST APIs for search and CRUD operations on records and persistent
      identifiers.
- `invenio-records-ui <https://invenio-records-ui.readthedocs.io>`_
    - User interface for displaying records.
- `invenio-search <https://invenio-search.readthedocs.io>`_
    - Elasticsearch integration module for Invenio.
- `invenio-search-js <https://inveniosoftware.github.io/invenio-search-js/>`_
    - AngularJS search application for displaying records from the REST API.
- `invenio-search-ui <https://invenio-search-ui.readthedocs.io>`_
    - User interface for searching records.

